@@ -370,9 +370,9 @@ sub _set_cgo_flags {
     my $bf = Dpkg::BuildFlags->new();
     $bf->load_config();
 
-    if ({$bf->get_features("optimize")}->{"lto"}) {
+    if ($bf->has_features("optimize") and {$bf->get_features("optimize")}->{"lto"}) {
         # cgo doesn't support LTO #1013102, https://golang.org/issues/43505
-        warning("LTO opimize is enable in buildflags. But cgo doesn't support it. " .
+        warning("LTO optimize is enable in buildflags. But cgo doesn't support it. " .
                 "LTO flags will be stripped in cgo.");
     }
 
@@ -380,10 +380,9 @@ sub _set_cgo_flags {
     foreach my $flag (@flags) {
         if (! exists $ENV{"CGO_" . $flag}) {
             $bf->strip($flag, "-ffat-lto-objects -flto=auto");
-            if (dpkg_architecture_value("DEB_HOST_ARCH") eq "i386") {
-                # https://github.com/golang/go/issues/54313
-                $bf->strip($flag, "-fstack-protector-strong");
-            }
+            # https://golang.org/issues/54313
+            # https://github.com/golang/go/commit/365ca694
+            $bf->strip($flag, "-fstack-protector-strong");
             $ENV{"CGO_" . $flag} = $bf->get($flag);
         }
     }
